@@ -208,7 +208,7 @@ func init() {
 	CommandHelp["match-replicas"] = `
   Matches all replicas of a given instance under another (destination) instance. This is a (faster) shortcut
   to matching said replicas one by one under the destination instance. In fact, this bulk operation is highly
-  optimized and can execute in orders of magnitue faster, depeding on the nu,ber of replicas involved and their
+	optimized and can execute in orders of magnitue faster, depending on the number of replicas involved and their
   respective position behind the instance (the more replicas, the more savings).
   The instance itself may be crashed or inaccessible. It is not contacted throughout the operation. Examples:
 
@@ -254,7 +254,7 @@ func init() {
   local master of its siblings, using Pseudo-GTID. It is uncertain that there *is* a replica that will be able to
   become master to all its siblings. But if there is one, orchestrator will pick such one. There are many
   constraints, most notably the replication positions of all replicas, whether they use log_slave_updates, and
-  otherwise version compatabilities etc.
+  otherwise version compatibilities etc.
   As many replicas that can be regrouped under promoted slves are operated on. The rest are untouched.
   This command is useful in the event of a crash. For example, in the event that a master dies, this operation
   can promote a candidate replacement and set up the remaining topology to correctly replicate from that
@@ -324,7 +324,7 @@ func init() {
   Undo a detach-replica operation. Reverses the binlog change into the original values, and
   resumes replication. Example:
 
-  orchestrator -c reattach-replica -i detahced.replica.whose.replication.will.amend.com
+  orchestrator -c reattach-replica -i detached.replica.whose.replication.will.amend.com
 
   Issuing this on an attached (i.e. normal) replica will do nothing.
 	`
@@ -340,7 +340,7 @@ func init() {
   Undo a detach-replica-master-host operation. Reverses the hostname change into the original value, and
   resumes replication. Example:
 
-  orchestrator -c reattach-replica-master-host -i detahced.replica.whose.replication.will.amend.com
+  orchestrator -c reattach-replica-master-host -i detached.replica.whose.replication.will.amend.com
 
   Issuing this on an attached (i.e. normal) replica will do nothing.
 	`
@@ -397,7 +397,7 @@ func init() {
   Get binlog file:pos of entry given by --pattern (exact full match, not a regular expression) in a given instance.
   This will search the instance's binary logs starting with most recent, and terminate as soon as an exact match is found.
   The given input is not a regular expression. It must fully match the entry (not a substring).
-  This is most useful when looking for uniquely identifyable values, such as Pseudo-GTID. Example:
+  This is most useful when looking for uniquely identifiable values, such as Pseudo-GTID. Example:
 
   orchestrator -c find-binlog-entry -i instance.to.search.on.com --pattern "insert into my_data (my_column) values ('distinct_value_01234_56789')"
 
@@ -480,7 +480,7 @@ func init() {
       -i not given, implicitly assumed local hostname
 
   Instance must be already known to orchestrator. Topology is generated by orchestrator's mapping
-  and not from synchronuous investigation of the instances. The generated topology may include
+  and not from synchronous investigation of the instances. The generated topology may include
   instances that are dead, or whose replication is broken.
 	`
 	CommandHelp["all-instances"] = `
@@ -612,7 +612,7 @@ func init() {
       assuming some_alias is a known cluster alias (see ClusterNameToAlias or DetectClusterAliasQuery configuration)
 	`
 	CommandHelp["instance-status"] = `
-  Output short status on a given instance (name, replication status, noteable configuration). Example2:
+  Output short status on a given instance (name, replication status, notable configuration). Example2:
 
   orchestrator -c instance-status -i instance.to.investigate.com
 
@@ -631,7 +631,7 @@ func init() {
 
 	CommandHelp["discover"] = `
   Request that orchestrator cotacts given instance, reads its status, and upsert it into
-  orchestrator's respository. Examples:
+  orchestrator's repository. Examples:
 
   orchestrator -c discover -i instance.to.discover.com:3306
 
@@ -655,7 +655,7 @@ func init() {
 	`
 	CommandHelp["begin-maintenance"] = `
   Request a maintenance lock on an instance. Topology changes require placing locks on the minimal set of
-  affected instances, so as to avoid an incident of two uncoordinated operations on a smae instance (leading
+  affected instances, so as to avoid an incident of two uncoordinated operations on a same instance (leading
   to possible chaos). Locks are placed in the backend database, and so multiple orchestrator instances are safe.
   Operations automatically acquire locks and release them. This command manually acquires a lock, and will
   block other operations on the instance until lock is released.
@@ -680,7 +680,7 @@ func init() {
   Mark an instance as downtimed. A downtimed instance is assumed to be taken care of, and recovery-analysis does
   not apply for such an instance. As result, no recommendation for recovery, and no automated-recovery are issued
   on a downtimed instance.
-  Downtime is different than maintanence in that it places no lock (mainenance uses an exclusive lock on the instance).
+  Downtime is different than maintenance in that it places no lock (mainenance uses an exclusive lock on the instance).
   It is OK to downtime an instance that is already downtimed -- the new begin-downtime command will override whatever
   previous downtime attributes there were on downtimes instance.
   Note that orchestrator automatically assumes downtime to be expired after MaintenanceExpireMinutes (hard coded value).
@@ -801,17 +801,17 @@ func init() {
 	CommandHelp["register-candidate"] = `
   Indicate that a specific instance is a preferred candidate for master promotion. Upon a dead master
   recovery, orchestrator will do its best to promote instances that are marked as candidates. However
-  orchestrator cannot guarantee this will always work. Issues like version compatabilities, binlog format
+  orchestrator cannot guarantee this will always work. Issues like version compatibilities, binlog format
   etc. are limiting factors.
   You will want to mark an instance as a candidate when: it is replicating directly from the master, has
   binary logs and log_slave_updates is enabled, uses same binlog_format as its siblings, compatible version
   as its siblings. If you're using DataCenterPattern & PhysicalEnvironmentPattern (see configuration),
   you would further wish to make sure you have a candidate in each data center.
   Orchestrator first promotes the best-possible replica, and only then replaces it with your candidate,
-  and only if both in same datcenter and physical enviroment.
+  and only if both in same datcenter and physical environment.
   An instance needs to continuously be marked as candidate, so as to make sure orchestrator is not wasting
   time with stale instances. Orchestrator periodically clears candidate-registration for instances that have
-  not been registeres for over CandidateInstanceExpireMinutes (see config).
+  not been registers for over CandidateInstanceExpireMinutes (see config).
   Example:
 
   orchestrator -c register-candidate -i candidate.instance.com
