@@ -35,7 +35,7 @@ import (
 	"github.com/openark/orchestrator/go/kv"
 	ometrics "github.com/openark/orchestrator/go/metrics"
 	"github.com/openark/orchestrator/go/process"
-	"github.com/openark/orchestrator/go/raft"
+	orcraft "github.com/openark/orchestrator/go/raft"
 	"github.com/openark/orchestrator/go/util"
 	"github.com/patrickmn/go-cache"
 	"github.com/rcrowley/go-metrics"
@@ -52,6 +52,7 @@ const (
 // that were requested for discovery.  It can be continuously updated
 // as discovery process progresses.
 var discoveryQueue *discovery.Queue
+var deadInstancesDiscoveryQueue *discovery.Queue
 var snapshotDiscoveryKeys chan inst.InstanceKey
 var snapshotDiscoveryKeysMutex sync.Mutex
 
@@ -66,6 +67,8 @@ var isRaftHealthyGauge = metrics.NewGauge()
 var isRaftLeaderGauge = metrics.NewGauge()
 var discoveryMetrics = collection.CreateOrReturnCollection(discoveryMetricsName)
 
+var deadInstancesDiscoveryQueueLengthGauge = metrics.NewGauge()
+
 var isElectedNode int64 = 0
 
 var recentDiscoveryOperationKeys *cache.Cache
@@ -180,6 +183,38 @@ func handleDiscoveryRequests() {
 			}
 		}()
 	}
+
+	if config.Config.DeadInstanceDiscoveryMaxConcurrency > 0 {
+		deadInstancesDiscoveryQueue = discovery.CreateOrReturnQueue("DEADINSTANCES")
+
+		// Register dead instances queue gauge only if the queue exists
+		metrics.Register("discoveries.dead_instances_queue_length", deadInstancesDiscoveryQueueLengthGauge)
+		ometrics.OnMetricsTick(func() {
+			deadInstancesDiscoveryQueueLengthGauge.Update(int64(deadInstancesDiscoveryQueue.QueueLen()))
+		})
+
+		// create a pool of discovery workers
+		for i := uint(0); i < config.Config.DeadInstanceDiscoveryMaxConcurrency; i++ {
+			go func() {
+				for {
+					instanceKey := deadInstancesDiscoveryQueue.Consume()
+					// Possibly this used to be the elected node, but has
+					// been demoted, while still the queue is full.
+					if !IsLeaderOrActive() {
+						log.Debugf("Node apparently demoted. Skipping discovery of %+v. "+
+							"Remaining queue size: %+v", instanceKey, deadInstancesDiscoveryQueue.QueueLen())
+						deadInstancesDiscoveryQueue.Release(instanceKey)
+						continue
+					}
+
+					DiscoverInstance(instanceKey)
+					deadInstancesDiscoveryQueue.Release(instanceKey)
+				}
+			}()
+		}
+	} else {
+		deadInstancesDiscoveryQueue = discoveryQueue
+	}
 }
 
 // DiscoverInstance will attempt to discover (poll) an instance (unless
@@ -236,13 +271,21 @@ func DiscoverInstance(instanceKey inst.InstanceKey) {
 	discoveriesCounter.Inc(1)
 
 	// First we've ever heard of this instance. Continue investigation:
-	instance, err = inst.ReadTopologyInstanceBufferable(&instanceKey, config.Config.BufferInstanceWrites, latency)
+	skipped := false
+	instance, skipped, err = inst.ReadTopologyInstanceBufferable(&instanceKey, config.Config.BufferInstanceWrites, latency)
 	// panic can occur (IO stuff). Therefore it may happen
 	// that instance is nil. Check it, but first get the timing metrics.
 	totalLatency := latency.Elapsed("total")
 	backendLatency := latency.Elapsed("backend")
 	instanceLatency := latency.Elapsed("instance")
 
+	if skipped {
+		if config.Config.EnableDiscoveryFiltersLogs {
+			log.Infof("discoverInstance: skipping discovery of %+v because its replication user matches DiscoveryIgnoreReplicationUsernameFilters", instanceKey)
+		}
+		return
+	}
+
 	if instance == nil {
 		failedDiscoveriesCounter.Inc(1)
 		discoveryMetrics.Append(&discovery.Metric{
@@ -288,14 +331,33 @@ func DiscoverInstance(instanceKey inst.InstanceKey) {
 			continue
 		}
 
-		if replicaKey.IsValid() {
+		if !replicaKey.IsValid() {
+			continue
+		}
+
+		dead, recheck := inst.DeadInstancesFilter.InstanceRecheckNeeded(&replicaKey)
+		if dead {
+			if recheck {
+				deadInstancesDiscoveryQueue.Push(replicaKey)
+			}
+			// dead, but not recheck time
+			continue
+		} else {
 			discoveryQueue.Push(replicaKey)
 		}
 	}
 	// Investigate master:
 	if instance.MasterKey.IsValid() {
 		if !inst.FiltersMatchInstanceKey(&instance.MasterKey, config.Config.DiscoveryIgnoreMasterHostnameFilters) {
-			discoveryQueue.Push(instance.MasterKey)
+			dead, recheck := inst.DeadInstancesFilter.InstanceRecheckNeeded(&instance.MasterKey)
+
+			if dead {
+				if recheck {
+					deadInstancesDiscoveryQueue.Push(instance.MasterKey)
+				}
+			} else {
+				discoveryQueue.Push(instance.MasterKey)
+			}
 		}
 	}
 }
@@ -365,7 +427,19 @@ func onHealthTick() {
 	if len(instanceKeys) > 0 {
 		for _, instanceKey := range instanceKeys {
 			if instanceKey.IsValid() {
-				discoveryQueue.Push(instanceKey)
+				dead, recheck := inst.DeadInstancesFilter.InstanceRecheckNeeded(&instanceKey)
+				if dead {
+					if recheck {
+						// this is a dead instance that needs recheck
+						deadInstancesDiscoveryQueue.Push(instanceKey)
+					}
+					// If the instance is dead, but it is not a time to recheck it
+					// it will be filtered out here.
+					continue
+				} else {
+					// this is a healthy instance that needs recheck
+					discoveryQueue.Push(instanceKey)
+				}
 			}
 		}
 	}
